@@ -1,36 +1,8 @@
-/////////////////////////////////////////////////////////////////////////////
-//
-// Project:     SMB kioslave for KDE
-//
-// File:        kio_smb.h
-//
-// Abstract:    The main kio slave class declaration.  For convenience,
-//              in concurrent development, the implementation for this class
-//              is separated into several .cpp files -- the file containing
-//              the implementation should be noted in the comments for each
-//              member function.
-//
-// Author(s):   Matthew Peterson <mpeterson@caldera.com>
-//
-//---------------------------------------------------------------------------
-//
-// Copyright (c) 2000  Caldera Systems, Inc.
-//
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 2.1 of the License, or
-// (at your option) any later version.
-//
-//     This program is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU Lesser General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with this program; see the file COPYING.  If not, please obtain
-//     a copy from https://www.gnu.org/copyleft/gpl.html
-//
-/////////////////////////////////////////////////////////////////////////////
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2000 Caldera Systems, Inc.
+    SPDX-FileContributor: Matthew Peterson <mpeterson@caldera.com>
+*/
 
 #ifndef KIO_SMB_H_INCLUDED
 #define KIO_SMB_H_INCLUDED
@@ -79,13 +51,13 @@ extern "C" {
 //---------------------------
 #include "smburl.h"
 
-#define MAX_XFER_BUF_SIZE 65534
 
 using namespace KIO;
 
 class SMBSlave : public QObject, public KIO::SlaveBase
 {
     Q_OBJECT
+    friend class SMBCDiscoverer;
 
 private:
     class SMBError
